@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# Application Name - Health Check V1.2.1-2
+# Application Name - Health Check V1.2.1-3
 # Date 17 February 2010
 # Author - Greg Roberts (Noobmonkey @ Maemo Talk)
 # Contact - Me@Greg-roberts.com
@@ -666,7 +666,7 @@ class Ui_MainWindow(QtGui.QMainWindow):
 		bus = dbus.SessionBus()
 		proxy = bus.get_object('org.freedesktop.Notifications', '/org/freedesktop/Notifications')
 		interface = dbus.Interface(proxy,dbus_interface='org.freedesktop.Notifications')
-		interface.Notify('HealthCheck', 0, 'general_refresh', 'Sound Test', 'Testing Stero/Mono Sound', [], {}, 3000)
+		interface.Notify('HealthCheck', 0, 'general_refresh', 'Sound Test', 'Testing Stereo/Mono Sound', [], {}, 3000)
 		print "** Starting Stereo Test **"
 		bb = 'pacat --channels=2 ' + '/usr/share/sounds/' + self.sound_lst.currentText()
 		bb = str(bb)
